petitRADTRANS
=============

**An easy-to-use Python package for calculating exoplanet spectra**

Welcome to the repository of petitRADTRANS, an easy-to-use code for the calculation of exoplanet spectra.
petitRADTRANS allows the calculation of emission or transmission spectra, at low or high resolution, clear or cloudy,
and includes a retrieval module to fit a petitRADTRANS model to your spectral data.


Documentation
-------------

The code documentation, installation guide, and tutorial can be found at `https://petitradtrans.readthedocs.io <https://petitradtrans.readthedocs.io>`_.

Attribution
-----------

If you use petitRADTRANS in your work, please cite the petitRADTRANS
paper (`Mollière et al. 2019 <https://arxiv.org/abs/1904.11504>`_).

License
-------

Copyright 2019-2023 Paul Mollière

petitRADTRANS is available under the MIT license.
See the LICENSE file for more information.
